/*jslint undef: true, widget: true, browser: true, onevar: true, eqeqeq: true, laxbreak: true */
/*global $ isArray iw_js_data */

var IW = {
    icons: {
        colors: {
            _PREFIX: 'text-',
            _RESET : 'text-reset',
            WARNING: 'text-warning',
            SUCCESS: 'text-success',
            DANGER : 'text-danger',
            INFO   : 'text-info'
        },

        _BASE  : 'mdi',
        _PREFIX: 'mdi-',

        ALERT       : 'mdi-alert',
        ALERT_CIRCLE: 'mdi-alert-circle',
        BLANK       : 'mdi-blank',
        CLOSE       : 'mdi-close-circle',
        INFO        : 'mdi-help-circle',
        MINUS       : 'mdi-minus',
        NEGATIVE    : 'mdi-alert-octagon',
        PAUSE       : 'mdi-pause',
        PENDING     : 'mdi-loading',
        PLUS        : 'mdi-plus',
        POSITIVE    : 'mdi-check-bold',
        RESTART     : 'mdi-restart',
        SPIN        : 'mdi-spin',
        STAR        : 'mdi-star',
        START       : 'mdi-play',
        STOP        : 'mdi-stop',
        SUB_OFF     : 'mdi-bell-off',
        SUB_ON      : 'mdi-bell',
    },

    states: {
        _BASE  : 'badge',
        _PREFIX: 'badge-',

        ALERT   : 'badge-warning',
        NEGATIVE: 'badge-danger',
        NEUTRAL : 'badge-info',
        POSITIVE: 'badge-success',
        DISABLED: 'badge-light'
    },

    /**
     * Determines if we're in nodeworx or siteworx
     * @return string
     */
    getIWEnv: function () {
        return iw_js_data.iw_env.env;
    },

    getSuccessBannerTimeout: function () {
        return iw_js_data.iw_env.success_banner_timeout;
    },

    debug: { io: [] },
    registry: {},
    is_unloading: false
};

var iw_lib = {
    redirect_timeout: 2000,
    /**
     * Updates the class of an iw_message element
     *
     * @param HTMLElement el
     * @param string      new_class
     */
    updateStatusClass: function ( el, new_class ) {
        el = this.getEl(el);
        if (new_class) {
            iw_lib.removePrefixedClass(el, IW.states._PREFIX);
            $(el).addClass(new_class);
        }
    },

    getEl: function ( id_or_el ) {
        let el;
        if (typeof id_or_el === 'string') {
            el = document.getElementById(id_or_el);
        } else {
            el = id_or_el;
        }

        return el;
    },

    _modalMasks: {},

    /**
     * Toggles the iworx spinner.
     *
     * @param HTMLElement el
     */
    toggleSpinner: function ( el ) {
        if ( $(el).hasClass(IW.icons.PENDING) ) {
            this.removePrefixedClass(el, IW.icons._PREFIX);
        } else {
            this.removePrefixedClass(el, IW.icons._PREFIX);
            $(el).addClass(IW.icons.PENDING);
            $(el).addClass(IW.icons.SPIN);
        }
    },

    /**
     * Updates an iw_message originally generated by smarty
     *
     * input.el        => JS Element reference to what you're updating
     * input.new_class => string (optional) - new classname to use for the element
     * input.message   => string (optional) - new message
     *
     * @param object input
     */
    updateIWMessage: function ( input ) {
        let el = input.el,
        new_class = input.new_class || null,
        message = input.message || null;

        if ( !el ) {
            // To stop us from making stupid javascript mistakes because
            alert("The element which was passed in is null, so JS will now " +
             "silently fail.  Just warning you.");
        }

        iw_lib.updateStatusClass(el, new_class);

        if (message) {
            if ($(el).hasClass('iw-status') || $(el).hasClass(IW.states._BASE)) {
                el.innerHTML = message;
            } else {
                // This is probably dead code for the 4-div messages for rounded corners old-school
                el.innerHTML = message;

                //el.getElementsByTagName('div')[2].innerHTML = message;
            }
        }
    },

    updateIWIcon: function ( el, new_class, new_color ) {
        if ( !el || !el.className ) {
            return;
        }

        if (new_color) {
            iw_lib.removePrefixedClass(el, IW.icons.colors._PREFIX);
        }

        iw_lib.removePrefixedClass(el, IW.icons._PREFIX);

        $(el).addClass(new_class);

        if (new_color) {
            $(el).addClass(new_color);
        }

        if (new_class === IW.icons.PENDING) {
            $(el).addClass(IW.icons.SPIN);
        }
    },

    removePrefixedClass: function (el, prefix) {
        let existing_classes = el.className.split(' '),
            class_length     = existing_classes.length,
            prefix_length    = prefix.length,
            i;

        for (i=0; i < class_length; ++i) {
            if ( existing_classes[i].substr(0, prefix_length) === prefix ) {
                $(el).removeClass(existing_classes[i]);
            }
        }
    },

    /*
     * Puts a message on screen in a Panel
     * @param string body
     * @param string header (optional)
     */
    iw_message: function ( body, header ) {
        header = header || '##LG_JSONSYSTEMERRORMESSAGE##';

        this.popupModal(body, header);
    },

    /**
     * Cached instance of a YUI draggable panel
     */
    iw_popup_panel: null,
    iw_modal_popup: null,

    popupRightModal: function (content, header) {
        this._popupAnyModal('#iw-right-modal', content, header);
    },

    _popupAnyModal(selector, content, header) {
        let modal = $(selector);

        modal.find('.modal-title').html(header);
        modal.find('.modal-body').html(content);
        modal.modal('show');
    },

    popupModal: function (content, header) {
        this._popupAnyModal('#iw-center-modal', content, header);
    },

    _correctModalPopupWidth: function ( minWidth ) {
        var p = this.iw_modal_popup,
        w = p.element.clientWidth;

        minWidth = minWidth || 125;

        if (w > ($(window).width() * 0.85)) {
            // This is for older IE's that just maximize the width
            w = 650;
        }

        w = Math.max(w, minWidth);

        p.cfg.setProperty('width', w + 'px');
    },

    _getPopupHeader: function ( header ) {
        return '<table><tr>' +
        '<td class="l">' +
        // span hack to make IE 6 pay attention to white-space: nowrap
        '<span style="white-space: nowrap">' + header + '</span>' +
        '</td>' +
        '<td class="r">&nbsp;</td>' +
        '</tr></table>';
    },

    /**
     * Displays a draggable YUI panel
     *
     * So, this feels a bit shitty but here's what's going on.  When you try to
     * append a YUI panel to a node it will inheret all of its CSS properties,
     * which makes perfect sense.  BUT, this means that how the panels look is
     * totally unpredictable so it's a problem.  What we need to do is get the
     * XY position of the element and create the panel at that location.
     *
     * @param string      content
     * @param string      header
     * @param HTMLElement el        (see above) Element you want to the panel to
     *                              showup near, give or take.
     * @param boolean     dont_show (optional).  Just build the panel, don't show it
     * @param boolean     center    (optional).  Center the panel on screen, or put relative
     *                              to el.
     */
    iw_popup: function ( content, header, el, dont_show, center ) {
        // Note - this is currently only used in websetup and graphs, which are both broken
        let xy_config;

        if ( !center ) {
            center = false; // default centering
        }

        dont_show = Boolean(dont_show);  // make sure we're a boolean.

        if ( !iw_lib.iw_popup_panel ) {
            iw_lib.iw_popup_panel = new YAHOO.widget.Panel("iw-popup", {
                constraintoviewport: true,
                underlay: "shadow",
                visible: false,
                close: true,
                draggable: true,
                fixedcenter: center,
                width: 350 + "px"});
            YAHOO.util.Dom.addClass(iw_lib.iw_popup_panel.element, 'iw-popup');

            // Subscribe an anonymous function to clear the body when hiding
            iw_lib.iw_popup_panel.hideEvent.subscribe(
                function () {
                    this.setBody('');
                    this.setHeader('');
                }
            );
        }
        this.iw_popup_panel.setHeader(this._getPopupHeader(header));

        if ( center ) {
            iw_lib.iw_popup_panel.center();
        } else {
            xy_config = [ YAHOO.util.Dom.getY(el) + 10,
                        YAHOO.util.Dom.getY(el) + 10 ];
            iw_lib.iw_popup_panel.cfg.setProperty('xy', xy_config);
        }

        iw_lib.iw_popup_panel.cfg.setProperty('zIndex', '10000');
        iw_lib.iw_popup_panel.setBody(content.replace(/\n/g, '<br>'));
        iw_lib.iw_popup_panel.render(document.body);

        // sometimes we may want to build the panel, not now show it right away.
        if ( dont_show !== true ) {
            iw_lib.iw_popup_panel.show();
        }
    },

    resetPopupWidth: function ( center ) {
        iw_lib.iw_popup_panel.cfg.setProperty('width', 'auto');
        if ( center ) {
            iw_lib.iw_popup_panel.center();
        }
    },

    banner_panel: null,

    /**
     */
    iw_message_banner: function ( text, textclass ) {
        if ( !text ) {
            return;
        }

        let icon = 'info';
        let timeout = IW.getSuccessBannerTimeout();
        let classLookup = {
            "iw-negative": "error",
            "iw-positive": "success"
        };

        if (classLookup[textclass]) {
            icon = classLookup[textclass];
        }

        text = text.replace(/\n/g, '<br>');

        // TIMDO: true sticky is broken inside Hyper - it changes the timeout to 3000
        if (icon === 'error') {
            timeout = 600000;
        }

        $.NotificationApp.send(
            undefined,
            text,
            'top-center',
            'rgba(0,0,0,0.2)',
            icon,
            timeout,
            5 // TIMDO: stack doesn't seem to work for some reason
        );
    },
};

// This makes it possible to easily "extend" existing objects
if ( typeof Object.beget !== 'function' ) {
    Object.beget = function ( o ) {
        var F       = function () {};
        F.prototype = o;
        return new F();
    };
}

// Add the array indexOf function for ie6
if ( !Array.indexOf ) {
    Array.prototype.indexOf = function ( obj ) {
        var i, length = this.length;
        for (i=0; i<length; i++) {
            if ( this[i] === obj ) {
                return i;
            }
        }
        return -1;
    };
}

/**
 * OLD FUNCTIONS START HERE - NEWER FUNCTIONS BELONG ABOVE THIS
 */

/**
 * simple browser detection.
 */

var iw_body = $('body')[0];
var isOpera = $(iw_body).hasClass('iw_opera');
var isIE = $(iw_body).hasClass('iw_ie');
var isMoz = $(iw_body).hasClass('iw_ff') ||
            $(iw_body).hasClass('iw_moz');

/**
 * function used ton confirm multi-checkbox actions
 * via a select onchange call
 * @param selectobj: the select object that triggers the submit
 * @param checkboxesVarname: the string that is the name of the checkboxes
 *        involved
 * @param boxesText: text that describes what the list of checkboxes actually is
 *                   (used in confirm dialog)
 * @param confirmText: almost always ##LG_CONFIRM_ACTION##
 * @param emptySetText: text to alert user with if no boxes are checked

 */

function confirmSubmitCheckbox(
    selectobj,
    checkboxesVarname,
    boxesText,
    confirmText,
    emptySetText,
    xhrrequest
) {
    var boxes, boxes_length, formobj, onecheck, answer, action, i, params;

    if (!boxesText) {
        // it's "the new way".  I know this is ghetto.  Will change at some point.
        params = checkboxesVarname;
        selectobj = params.selectobj;
        checkboxesVarname = params.checkname;
        boxesText = params.boxtext;
        confirmText = params.confirmtext;
        emptySetText = params.emptytext;
        xhrrequest = params.xhrrequest;
    }
    // check the params
    if ( !selectobj || typeof selectobj !== 'object' ) {
        alert("invalid 'selectobj' param.  should be a SELECT object");
        return false;
    }

    formobj = selectobj.form;

    if ( !formobj || typeof formobj  !== 'object' ) {
        alert("invalid 'formobj' param.  should be a FORM object");
        return false;
    }

    if ( !checkboxesVarname || typeof checkboxesVarname !== 'string' ) {
        alert("invalid 'checkboxesVarname' param.  Should be a string, the name of the checkboxes var.");
        return false;
    }
    if ( !boxesText || typeof boxesText !== 'string' ) {
        alert("invalid 'boxesText' param.  Should be a string, language entry decribing the list of checkboxes.");
        return false;
    }
    if ( !confirmText || typeof confirmText !== 'string' ) {
        alert("invalid 'confirmText' param.  Should be a string.");
        return false;
    }
    if ( !emptySetText || typeof emptySetText !== 'string' ) {
        alert("invalid 'emptySetText' param.  Should be a string.");
        return false;
    }

    // first make sure something is checked.
    boxes        = document.getElementsByName(checkboxesVarname);
    boxes_length = boxes.length;
    onecheck     = false;

    for (i = 0; i < boxes_length; i++) {
        if ( boxes[i].checked ) {
            onecheck = true;
            break;
        }
    }

    if ( !onecheck ) {
        alert(emptySetText);
        selectobj.selectedIndex = 0;
        return( false );
    }

    answer = confirm(confirmText + " : " +
             selectobj.options[selectobj.selectedIndex].text.toUpperCase() +
               " " + boxesText + "?");

    if ( answer ) {
        action = selectobj.options[selectobj.selectedIndex].value;
        if ( xhrrequest && xhrrequest.getAction() === action ) {
            selectobj.disabled = 1;
            xhrrequest.route();
        } else {
            formobj.submit();
            selectobj.disabled = 1;
        }
    } else {
        selectobj.selectedIndex = 0;
        return false;
    }

}

/**
 * popup to confirm a deletion.
 *
 */

function confirmDelete( form, conditions, message )
{

}

/**
 * popUp a window given the URL
 *
 * @param URL
 * @param window name
 * @param width of window
 * @param height"
 */

function popUp(webpage, windowName, width, height)
{
    window.open(
        webpage,
        windowName,
        "scrollbars=yes,width="+width+", height="+height
    );
}

/**
 * highlight the bad forms elements on the page.
 *
 * @param list of elements.
 */
function highlightBadFormElem( /* variable no. of arguments */ )
{
    var elem, i, arg_length;
    if ( arguments.length < 1 ) {
        return;
    }
    arg_length = arguments.length;
    for (i = 0; i < arg_length; i++) {
        // Figure out if we were passed the object itself, or the object
        // name

        if ( typeof( arguments[i] ) === 'string' ) {
            elem = document.getElementById(arguments[i]);

            if ( elem !== null ) {
                elem.className = 'bad_form_element';
            }
        }
    }

    // Focus on the first element
    if ( typeof( arguments[0] ) === 'string' ) {
        document.getElementById(arguments[0]).focus();
    } else {
        arguments[0].focus();
    }
}

/**
 * remove the highlight from bad forms elements on the page.
 *
 * @param list of elements.
 */
function removeHighlightBadFormElem( /* variable no. of arguments */ )
{
    var elem, i, arg_length;
    if ( arguments.length < 1 ) {
        return;
    }

    arg_length = arguments.length;
    for (i = 0; i < arg_length; i++) {
        // Figure out if we were passed the object itself, or the object
        // name

        if ( typeof( arguments[i] ) === 'string' ) {
            elem = document.getElementById(arguments[i]);

            if ( elem !== null ) {
                elem.className = 'textbox';
            }
        }
    }

    // Focus on the first element
    if ( typeof( arguments[0] ) === 'string' ) {
        document.getElementById(arguments[0]).focus();
    } else {
        arguments[0].focus();
    }
}

/**
 * set checkboxes in the given form
 * to checked or unchecked.
 *
 * @param form
 * @param checkbox gropu name
 * @param true = checked.
 */

function setCheckboxes(formname, boxname, checkit)
{

    let boxes = document.forms[ formname ].elements[ boxname ],
      boxes_length = boxes.length,
      i;

    if ( !$.isArray(boxes) ) {
        if ( !boxes.disabled ) {
            boxes.checked = checkit;
        }
    } else {
        for (i = 0; i < boxes_length; i++) {
            if ( !boxes[i].disabled ) {
                boxes[i].checked = checkit;
            }
        }
    }

    return false;
}


function textboxSelect(oTextbox, iStart, iEnd)
{
    switch (arguments.length) {
        case 1:
            oTextbox.select();
      break;

        case 2:
            iEnd = oTextbox.value.length;
      break;

        case 3:
            iEnd = oTextbox.value.length;
            if ( isIE ) {
                var oRange = oTextbox.createTextRange();
                oRange.moveStart("character", iStart);
                oRange.moveEnd("character", -oTextbox.value.length + iEnd);
                oRange.select();
            } else if ( isMoz ) {
                oTextbox.setSelectionRange(iStart, iEnd);
            }
    }

    oTextbox.focus();
}

function textboxReplaceSelect(oTextbox, sText)
{
    let oRange, iStart;
    if ( isIE ) {
        oRange      = document.selection.createRange();
        oRange.text = sText;
        oRange.collapse(true);
        oRange.select();
    } else if ( isMoz ) {
        iStart         = oTextbox.selectionStart;
        oTextbox.value = oTextbox.value.substring(0, iStart) + sText + oTextbox.value.substring(oTextbox.selectionEnd, oTextbox.value.length);
        oTextbox.setSelectionRange(iStart + sText.length, iStart + sText.length);
    }

    oTextbox.focus();
}

function autocompleteMatch(sText, arrValues)
{
    let arr_length = arrValues.length,
        i;

    for (i = 0; i < arr_length; i++) {
        if ( arrValues[i].indexOf(sText) === 0) {
            return arrValues[i];
        }
    }

    return null;
}

function autocomplete(oTextbox, oEvent, arrValues)
{
    let iLen, sMatch;

    switch (oEvent.keyCode) {
        case 38: //up arrow
        case 40: //down arrow
        case 37: //left arrow
        case 39: //right arrow
        case 33: //page up
        case 34: //page down
        case 36: //home
        case 35: //end
        case 13: //enter
        case 9:  //tab
        case 27: //esc
        case 16: //shift
        case 17: //ctrl
        case 18: //alt
        case 20: //caps lock
        case 8:  //backspace
        case 46: //delete
      return true;

        default:
            textboxReplaceSelect(oTextbox, String.fromCharCode(isIE ? oEvent.keyCode : oEvent.charCode));
            iLen = oTextbox.value.length;

            sMatch = autocompleteMatch(oTextbox.value, arrValues);

            if ( sMatch !== null ) {
                oTextbox.value = sMatch;
                textboxSelect(oTextbox, iLen, oTextbox.value.length);
            }

      return false;
    }//end switch
}

/**
 * disable this component and submit
 */
function disableMe( comp, bval )
{
    comp.disabled = true;
    comp.value    = bval;
}
