var plesk_import_step_2 = {
    init: function () {
        let checks = $('.in-import');

        this.ips = $('.in-ipaddress');
        this.resellers = $('.in-reseller').get();

        $(this.ips).change(this.onIpChange);

        if (this.resellers) {
            for (reseller in this.resellers) {
                if (this.resellers.hasOwnProperty(reseller)) {
                    this.updateReseller(this.resellers[reseller]);
                }
            }

            $(this.resellers).change(this.onResellerChange);
        }

        this.initChecks(checks);
        this.initLogReader();
    },

    initLogReader: function () {
        let xml_file = document.getElementById('iw-in-plesk_import_xml').value;

        xml_file = xml_file.split('/');
        // Ditch the last bit
        xml_file.pop();

        this.logReader = Object.beget(showLogHandler);
        this.logReader.input = xml_file.pop();
        this.logReader.responder = 'ImportPleskLog';
        this.logReader.repeatEvery = 3000;

        $(document).on('plesk_import_step_2Submit', this.pleskLogShower);
    },

    pleskLogShower: function (e) {
        plesk_import_step_2.logReader.execute();
    },

    initChecks: function (checks) {
        $(checks).change(this.toggleRequired);
    },

    toggleRequired: function (e) {
        let tr            = $(this).closest('tr'),
            inputs        = $(tr).children('input'),
            inputs_length = inputs.length,
            i;

        for (i = 0; i < inputs_length; ++i) {
            if (this.checked) {
                $(inputs[i]).addClass('iw-form-req');
            } else {
                $(inputs[i]).removeClass('iw-form-req');
            }
            iw_form.clearStatus(inputs[i]);
        }
    },

    /**
     * Cache of ip select elements
     */
    ips: [],

    /**
     * Cache of reseller select elements
     */
    resellers: [],

    updateIps: function (select) {
        let reseller_id                          = select.value,
            ip_selects                           = $('#' + select.id + '_table .in-ipaddress'),
            ip_select_length                     = ip_selects.length,
            ips, i, create = false, filtered_ips = {};

        if (reseller_id === 'create') {
            reseller_id = 1;
            create = true;
        } else {
            reseller_id = parseInt(reseller_id, 10);
        }

        ips = iw_js_data.reseller_data.d[reseller_id].ips;

        if (create === true) {
            for (ip in ips) {
                if (ips.hasOwnProperty(ip)) {
                    if (iw_js_data.ips[ip].reseller === "yes") {
                        filtered_ips[ip] = ips[ip];
                    }
                }
            }
        } else {
            filtered_ips = ips;
        }

        for (i = 0; i < ip_select_length; ++i) {
            this.populateSelect(ip_selects[i], filtered_ips, '##LG_NO_IPS_AVAILABLE##');
        }
    },

    updateDbs: function (select) {
        let reseller_id      = select.value,
            db_selects       = $('#' + select.id + '_table .in-database_server'),
            db_select_length = db_selects.length,
            dbs, i;

        if (reseller_id === 'create') {
            reseller_id = 1;
        }

        dbs = iw_js_data.reseller_data.d[reseller_id].dbservers;

        for (i = 0; i < db_select_length; ++i) {
            this.populateSelect(db_selects[i], dbs, '##LG_DATABASE_SERVERS_EMPTY##');
        }
    },

    /**
     * Populates the select box given te assoicative array of options.
     */
    populateSelect: function (select, options, null_message) {
        let i                   = 0,
            current_value       = select.value,
            found_current_value = (options[current_value]) ? true : false,
            option;

        select.options.length = 0;

        iw_form.clearStatus(select);

        if (options && $.isArray(options) === false) {
            for (option in options) {
                if (option) {
                    if (option === current_value) {
                        found_current_value = true;
                    }

                    select.options.add(new Option(options[option], option), i);
                    ++i;
                }//end if
            }

            if (found_current_value === true && current_value) {
                select.value = current_value;
            } else {
                select.value = select.options[0].value;
            }
        } else {
            iw_form.markInvalid(select, null_message);
            select.options.add(new Option('##LG_ERRORS##', ''), i);
        }//end if
    },

    updateReseller: function (select) {
        plesk_import_step_2.updateIps(select);
        plesk_import_step_2.updateDbs(select);
    },

    onResellerChange: function (e) {
        plesk_import_step_2.updateReseller(e.target);
    },

    onIpChange: function (e) {
        let ip       = this.value,
            i        = 0,
            ip_count = plesk_import_step_2.ips.length,
            current_ip;
        if (iw_js_data.ips[ip].type === 'shared') {
            return;
        }

        for (i = 0; i < ip_count; ++i) {
            current_ip = plesk_import_step_2.ips[i];
            if (current_ip.id === this.id) {
                continue;
            }

            if (current_ip.value === ip) {
                iw_form.markInvalid(current_ip, '##LG_IMPORT_DEDICATED_IP_IN_USE##');
            }
        }
    }
};

plesk_import_step_2.init();
