/*jslint undef: true, widget: true, browser: true, onelet: true, eqeqeq: true */
/*global YAHOO,
         iw_ctrl_handler,
         iw_message,
         iw_message_banner,
         service_update_event,
         iw_lib,
         iw_js_data
 */

/**
 * Object that handles the firewall port status updating action
 */
let iw_ports_save = function () {
    let _controller = 'nodeworx/firewall',
        _action     = 'update',
        _form       = document.forms.ports;

    /**
     * Sets all the ports to neutral background color and the text to WAIT
     * for the boxes that have been changed
     * TODO: clean up this function
     */
    function _init()
    {

    }

    /**
     * turns all the port boxes to the neutral "blue" color
     */
    function _turnblue()
    {
        let i                  = 0,
            selects_pos        = $('.' + IW.states.POSITIVE),
            selects_neg        = $('.' + IW.states.NEGATIVE),
            open               = '##LG_OPEN##'.toLowerCase(),
            closed             = '##LG_CLOSED##'.toLowerCase(),
            selects_pos_length = selects_pos.length,
            selects_neg_length = selects_neg.length;

        for (i = 0; i < selects_pos_length; ++i) {
            if ($(selects_pos[i]).html().trim().toLowerCase() === open) {
                $(selects_pos[i]).removeClass(IW.states.POSITIVE);
                $(selects_pos[i]).addClass(IW.states.NEUTRAL);
            }
        }

        for (i = 0; i < selects_neg_length; ++i) {
            if ($(selects_neg[i]).html().trim().toLowerCase() === closed) {
                $(selects_neg[i]).removeClass(IW.states.NEGATIVE);
                $(selects_neg[i]).addClass(IW.states.NEUTRAL);
            }
        }
    }

    /**
     * turns all the port boxes to the correct red/green color based on their
     * open / closed status
     */
    function _colorize()
    {
        let i              = 0,
            toggles        = $('.' + IW.states.NEUTRAL).get(),
            open           = '##LG_OPEN##'.toLowerCase(),
            closed         = '##LG_CLOSED##'.toLowerCase(),
            toggles_length = toggles.length;

        for (i = 0; i < toggles_length; ++i) {
            if ($(toggles[i]).html().trim().toLowerCase() === open) {
                $(toggles[i]).removeClass(IW.states.NEUTRAL);
                $(toggles[i]).addClass(IW.states.POSITIVE);
            }
            if ($(toggles[i]).html().trim().toLowerCase() === closed) {
                $(toggles[i]).removeClass(IW.states.NEUTRAL);
                $(toggles[i]).addClass(IW.states.NEGATIVE);
            }
        }
    }

    /**
     * public interface starts here
     */
    return {
        /**
         * get action
         *
         * This is needed because the confirmSubmitCheckBoxes uses it to determine
         * if it should fire ajax or post normal style.
         * @return string
         */
        getAction: function () {
            return _action;
        },

        /**
         * Pass along the request to the iw_ctrl_handler
         */
        route: function () {
            _init();
            iw_ctrl_handler.execute(_form, iw_ports_save.complete, _controller, _action);
        },

        /*
         * Handle the xhr success.  Sets the ports to the correct background color.
         *
         * @param Object  r       The reply object
         * @param Boolean success If controller/action was successful, true
         */
        complete: function (r, success) {
            if (success) {
                let isrunning = $('#iw-stat-v-nodeworx-firewall').hasClass(IW.states.POSITIVE);
                if (isrunning) {
                    _colorize();
                } else {
                    _turnblue();
                }
                iw_lib.iw_message_banner(r.getReplyData().message, IW.states.POSITIVE);
            } else {
                iw_lib.iw_message(r.getReplyData().message);
            }
            document.ports.action.selectedIndex = 0;
            document.ports.action.disabled = 0;
            $('#spinner').css('visibility', 'hidden');
        },

        /**
         * an event handler, listens for changes to the service controls on the page
         */
        serviceStatusHandler: function () {
            let isrunning = $('#iw-stat-v-nodeworx-firewall').hasClass(IW.states.POSITIVE);
            if (isrunning) {
                _colorize();
            } else {
                _turnblue();
            }
        }
    };
}();

function togglePort(e)
{
    let box         = e.target,
        allboxes    = $('.' + IW.states._BASE),
        status      = $(box).html(),
        row         = $(box).closest('tr').children(),
        row_length  = row.length,
        i, key,
        open        = 'open',
        closed      = 'closed',
        input       = {
            ports         : $(row[3]).html(),
            security_token: iw_js_data.iw_env.security_token
    };

    allboxes.splice(0, 2);

    for (i = 4; i < row_length; ++i) {
        key = row[i].className.replace('td-', '');
        key = key.replace('_', '_flow_');
        if ($(box).is($(row[i]).children().first())) {
            if ($(box).html().trim() === '##LG_OPEN##') {
                input[key] = closed;
            } else {
                input[key] = open;
            }
        }
    }

    function complete(r, success)
    {
        if (success) {
            iw_lib.iw_message_banner(r.getReplyData().message, IW.states.POSITIVE);
            if ($(box).hasClass(IW.states.POSITIVE)) {
                $(box).removeClass(IW.states.POSITIVE);
                $(box).addClass(IW.states.NEGATIVE);
                $(box).html('##LG_CLOSED##');
            } else if ($(box).hasClass(IW.states.NEGATIVE)) {
                $(box).removeClass(IW.states.NEGATIVE);
                $(box).addClass(IW.states.POSITIVE);
                $(box).html('##LG_OPEN##');
            } else {
                if (status.toUpperCase().indexOf(closed.toUpperCase()) !== -1) {
                    $(box).html('##LG_OPEN##');
                } else {
                    $(box).html('##LG_CLOSED##');
                }
            }
        } else {
            iw_lib.iw_message_banner(r.getReplyData().message, IW.states.NEGATIVE);
            $(box).html(status);
        }//end if
        $('#port_access-shell').on('click', '.' + IW.states._BASE, togglePort);
        allboxes.css('cursor', 'pointer');
    }

    $(box).html('<i class="' + IW.icons._BASE + ' ' + IW.icons.PENDING + ' ' + IW.icons.SPIN + '"></i>');

    $('#port_access-shell').off('click', '.' + IW.states._BASE, togglePort);
    allboxes.css('cursor', 'wait');

    iw_ctrl_handler.execute(
        null,
        complete,
        'nodeworx/firewall',
        'updateCommit',
        input
    );
}

// subscribe to custom the onServiceStatusUpdate event
$('#iw-stat-v-nodeworx-firewall').bind('onServiceStatusUpdate', iw_ports_save.serviceStatusHandler);

window.onload = function () {
    $('#port_access-shell').on('click', '.' + IW.states._BASE, togglePort);
    $('#port_access-shell ' + '.' + IW.states._BASE).css('cursor', 'pointer');
};
