/*jslint undef: true, widget: true, browser: true, onelet: true, eqeqeq: true */
/*global YAHOO, iw_js_data, IW_PAYLOAD_DATA, iw_xhr, iw_lib, iw_ctrl_handler, iw_form */

var iw_payload, iw_payload_widget;

iw_payload = {
    init: function () {
        let payloads = $('.iw-payload').get();

        this.initEventHandlers(payloads);
        this.initBrowserHistory(payloads);
        this.initGroupClickHandlers(payloads);
    },

    initBrowserHistory: function (payloads) {
        let i, payload_count = payloads.length, state, temp, payload, data;

        for (i = 0; i < payload_count; ++i) {
            data = IW_PAYLOAD_DATA[payloads[i].id];
            state = data.pgn8state;

            payload = iw_payload_widget(payloads[i]);

            if (window.location.hash.substring(1).split('=')[0] == payload.id) {
                state = JSON.parse(decodeURIComponent(window.location.hash.split('=')[1]));
            }

            this.setData(state, payload);

            state = payload.getState();

            if (state !== JSON.stringify(data.pgn8state)) {
                payload.refresh();
                $(payload).trigger('restoreStateEvent');
            }

            payload.cache[state] = payload.getElement().innerHTML;

            $(window).on('hashchange', {'payload': payload}, this.historyStateChangeHandler);
        }//end for
    },

    parseState: function (state) {
        if (typeof state == 'string') {
            try {
                state = JSON.parse(state);
            } catch (e) {
                state = {l: 20, o: 0, or: null, d: 'asc'};
            }
        }
        return state;
    },

    setData: function (state, payload) {
        let value;
        state = this.parseState(state);

        for (value in state) {
            if (state.hasOwnProperty(value)) {
                payload.setValue(value, state[value]);
            }
        }
    },

    historyStateChangeHandler: function (e) {
        let parts, newState, payload;

        parts = window.location.hash.split('=');
        newState = JSON.parse(decodeURIComponent(parts[1]));
        payload = e.data.payload;

        if (parts[0].substring(1) !== payload.id) {
            return;
        }

        if (payload.ignoreCache() === true) {
            payload.setIgnoreCache(false);
            return;
        }

        if (payload.cache[newState]) {
            payload.getElement().innerHTML = payload.cache[newState];
            payload.clearState();
            iw_payload.setData(newState, payload);
            payload.reconnectForm();
            $(payload).trigger('restoreStateEvent');
            return;
        }

        if (newState !== payload.getState()) {
            iw_payload.setData(newState, payload);
            payload.refresh();
        }
    },

    initEventHandlers: function () {
        $(document).on('click', 'input.iw-check-all', this.checkAll);
        $(document).on('click', '.iw-sort a', this.sort);
        $(document).on('click', '.iw-pgn8 .iw-pgn8r', this.paginate);
        $(document).on('change', '.iw-pgn8 select', this.paginateJump);
        $(document).on('change', '.iw-payload-target-domain', this.changeTarget);
        $(document).on('click', 'a.iw-pgn8-all', this.viewAll);
        $(document).on('click', '.iw-payload-sortable', this.titleClickSort);
        $(document).on('change', '.iw-form-req', this.selectRow);
        $(document).on('change', '.iw-check-all', this.selectAllRow);
        $(document).on('click', '.iw-payload-refresh', this.refresh);
    },

    initGroupClickHandlers: function () {
        $(document).on('dblclick', 'tr.iw-payload-group-hd', this.toggleGroupDisplay);
        $(document).on('click', 'tr.iw-payload-group-hd .iw-collapse', this.toggleGroupDisplay);
    },

    selectRow: function (e) {
        let checkbox = e.target,
            row      = $(checkbox).closest('tr'),
            newclass = 'selected';

        if (checkbox.checked) {
            row.className += ' ' + newclass;
        } else {
            $(row).removeClass(newclass);
        }
    },

    selectAllRow: function (e) {
        let checks      = $('input[type=checkbox]'),
            check_count = checks.length,
            checkbox    = e.target,
            newclass    = 'selected',
            row,
            i;

        for (i = 0; i < check_count; ++i) {
            row = $(checks[i]).closest('tr');
            if (checks[i].disabled) {
                continue;
            }

            if (checkbox.checked && checkbox !== checks[i]) {
                row.className += ' ' + newclass;
            } else {
                $(row).removeClass(newclass);
            }
        }
    },

    viewAll: function (e) {
        let payload = iw_payload._getPayload(e);
        e.stopPropagation();
        e.preventDefault();

        payload.setLimit(0);
        payload.setOffset(0);
        payload.go();
    },

    paginate: function (e) {
        let payload = iw_payload._getPayload(e);

        e.stopPropagation();
        e.preventDefault();

        if (this.className.indexOf('-off') !== -1) {
            return;
        }

        payload.setOffset($(this).data('iw-offset'));

        if (payload.getLimit() === 0) {
            payload.setLimit(payload.initialLimit);
        }

        payload.go();
    },

    _getPayload: function (e) {
        let target = e.target,
            shell  = $(target).closest('.iw-payload');

        if (!shell.length) {
            shell = $(target).closest('.card').find('.iw-payload')[0];
        }

        return iw_payload_widget(shell);
    },

    paginateJump: function (e) {
        let payload = iw_payload._getPayload(e);
        e.stopPropagation();
        e.preventDefault();

        payload.setOffset(this.options[this.selectedIndex].value);
        payload.go();
    },

    toggleGroupDisplay: function (e) {
        let target = $(e.target).closest('tr'),
            parent,
            group_num,
            children,
            child,
            img;

        parent = $(target).closest('table');
        group_num = $(target).attr('data-iw-group-num');
        children = $('tr.group-num-' + group_num, parent);
        img = $('.iw-collapse', target)[0];

        if ($(img).hasClass(IW.icons.MINUS)) {
            iw_lib.updateIWIcon(img, IW.icons.PLUS);
        } else {
            iw_lib.updateIWIcon(img, IW.icons.MINUS);
        }

        for (child in children) {
            if (children.hasOwnProperty(child)) {
                child = children[child];
                if ($(child).hasClass('iw-hide')) {
                    $(child).removeClass('iw-hide');
                } else {
                    $(child).addClass('iw-hide');
                }
            }//end if has own property
        }//end for
    },

    titleClickSort: function (e) {
        let payload   = iw_payload._getPayload(e),
            target    = e.target,
            direction = 'asc',
            order     = 'up',
            i,
            td,
            a;

        if (target.tagName.toLowerCase() === 'i') {
            return;
        }

        if ($(target).hasClass('quickhelp')) {
            return;
        }

        td = $('.sorted', this);
        a = this.getElementsByTagName('a')[0];

        if (td[0]) {
            td = td[0];
            i = td.getElementsByTagName('i')[0];

            if ($(i).hasClass('up')) {
                direction = 'desc';
                order     = 'down';
            }
        }

        payload.setOrder(order, direction);
        payload.setOffset(0);
        payload.go();
    },

    refresh: function (e) {
        let payload = iw_payload._getPayload(e);
        e.stopPropagation();
        e.preventDefault();
        payload.refresh();
    },

    changeTarget: function (e) {
        let payload = iw_payload._getPayload(e);
        e.stopPropagation();
        e.preventDefault();
        payload.setValue('target_domain', $(this).val());
        payload.refresh();
    },

    sort: function (e) {
        let payload = iw_payload._getPayload(e),
            i       = this.getElementsByTagName('i')[0];
        e.stopPropagation();
        e.preventDefault();

        if ($(i).hasClass('up')) {
            payload.setOrder($(this).attr('class'), 'asc');
        } else {
            payload.setOrder($(this).attr('class'), 'desc');
        }
        payload.setOffset(0);
        payload.go();
    },

    checkAll: function (e) {
        let table       = $(this).closest('table'),
            checks      = $('input[type=checkbox]', table),
            check_count = checks.length,
            i;

        for (i = 0; i < check_count; ++i) {
            if (checks[i].disabled) {
                continue;
            }
            checks[i].checked = this.checked;
        }
    },

    markPayloadInProgress: function (eventType, payload, silent) {
        if (silent === false) {
            $(payload).addClass('iw-sorting');
        }
    },

    clearPayloadInProgress: function (eventType, payload) {
        $(payload).removeClass('iw-sorting');
    },

    widgets: {}
};

iw_payload_widget = function (id_or_el) {
    let el, form, input, _callback, _refreshCompleteEvent, _refreshBeginEvent,
        _getForm, timeout, _isRefreshed, _stateInput = {}, _getState, _ignoreCache,
        _refresh, _refreshAfterPeriod, _startAutoRefresh, _cache, _reconnectForm,
        _refreshOn, _initRefreshOn, _reconnectEl, _isInPopup;

    el = iw_lib.getEl(id_or_el);

    _ignoreCache = false;

    if (iw_payload.widgets[$(el).attr('id')]) {
        // if cached, return the cached instance
        return iw_payload.widgets[$(el).attr('id')];
    }

    _getForm = function () {
        let my_form = $('.iw-form', el);
        return my_form[0];
    };

    form = _getForm();

    if (!IW_PAYLOAD_DATA[$(el).attr('id')]) {
        IW_PAYLOAD_DATA[$(el).attr('id')] = {};
    }

    input = IW_PAYLOAD_DATA[$(el).attr('id')];
    input.iw_refresh_action = form.iw_refresh_action.value;
    input.iw_refresh_ctrl = form.iw_refresh_ctrl.value;

    if (form.iw_cache_key) {
        input.iw_cache_key = form.iw_cache_key.value;
    }

    input.security_token = iw_js_data.iw_env.security_token;

    $(el).bind('refreshBegin', iw_payload.markPayloadInProgress);
    $(el).bind('refreshComplete', iw_payload.clearPayloadInProgress);

    _cache = {};

    _callback = function (reply, success) {
        let data = reply.getReplyData();
        if (success === true) {
            el.innerHTML = data.payload;
            _reconnectEl();
            _reconnectForm();
            $(el).trigger('refreshComplete', el);
            _cache[_getState()] = data.payload;
        }
    };

    _reconnectEl = function () {
        el = document.getElementById($(el).attr('id'));
    };

    _reconnectForm = function () {
        // Reconnect the form element
        form = _getForm();
        iw_form.initFormEvents(form);
    };

    _isRefreshed = function () {
        let period = parseInt(form.iw_refresh_period.value, 10);
        return period > 0;
    };

    _refresh = function (silent) {
        silent = (silent === true);
        $(el).trigger('refreshBegin', [el, silent]);
        input.pgn8state = _stateInput;
        iw_ctrl_handler.execute(null, _callback, 'index', 'livePayloadCommit', input);
    };

    _refreshAfterPeriod = function () {
        let period = form.iw_refresh_period.value * 1000;
        timeout = window.setTimeout(_refresh, period);
    };

    _startAutoRefresh = function () {
        if (_isRefreshed()) {
            $(el).bind('refreshComplete', _refreshAfterPeriod);
            _refreshAfterPeriod();
        }
    };

    _getState = function () {
        return JSON.stringify(_stateInput);
    };

    _refreshOn = function (action, ctrl) {
        if (ctrl === null) {
            ctrl = form.iw_ctrl_name.value;
        }

        iw_xhr.subscribeTo(_refresh, action, ctrl);
    };

    _initRefreshOn = function () {
        let i, pair;

        for (i in input.refresh_on) {
            if (input.refresh_on.hasOwnProperty(i)) {
                pair = input.refresh_on[i];
                _refreshOn(pair[0], pair[1]);
            }
        }
    };

    _isInPopup = function () {
        let panel = $(el).closest('.modal');

        return (panel) ? true : false;
    };

    _initRefreshOn();
    _startAutoRefresh();

    iw_payload.widgets[$(el).attr('id')] = {
        getElement: function () {
            return el;
        },
        getForm   : function () {
            return form;
        },
        getLimit  : function () {
            return parseInt(_stateInput.l, 10);
        },
        setLimit  : function (integer) {
            _stateInput.l = parseInt(integer, 10);
        },
        getOffset : function () {
            return parseInt(_stateInput.o, 10);
        },
        setOffset : function (integer) {
            _stateInput.o = parseInt(integer, 10);
        },
        getOrder  : function () {
            return _stateInput.or;
        },
        setOrder  : function (order, direction) {
            _stateInput.or = order;
            if (direction) {
                _stateInput.d = direction;
            }
        },

        markInProgress : function () {
            $(el).addClass('iw-sorting');
        },

        callback : _callback,
        isInPopup: _isInPopup,

        clearState      : function () {
            _stateInput = {};
        },
        getDirection    : function () {
            return _stateInput.d || 'asc';
        },
        getState        : _getState,
        setValue        : function (name, value) {
            _stateInput[name] = value;
        },
        getValue        : function (name) {
            if (_stateInput[name]) {
                return _stateInput[name];
            }
            return null;
        },
        reconnectForm   : _reconnectForm,
        refreshOn       : _refreshOn,
        refreshOnFailure: function (action, ctrl) {
            iw_xhr.subscribeTo(_refresh, action, ctrl, 'failure');
        },
        startAutoRefresh: _startAutoRefresh,
        stopAutoRefresh : function () {
            if (timeout) {
                window.clearTimeout(timeout);
                $(el).unbind('refreshComplete', _refreshAfterPeriod);
            }
        },
        /**
         * "go()" is used when the payload will be returning new results, ie pagination.
         *
         * Go adds history and records a navigable state conditionally - if the payload
         * in question is in the popup, then it won't, because that's a bad idea.
         */
        go                  : function () {
            _refresh();
            _ignoreCache = true;

            if (_isInPopup() === false) {
                var url = '#' + $(el).attr('id') + '=' + encodeURIComponent(_getState());
                history.pushState(null, null, url);
            }
        },
        /**
         * "refresh()" is used update the payload when content changes, ie "add" or "edit"
         *
         * Refresh DOES NOT add history
         */
        refresh             : function (silent) {
            silent = (silent === true);
            _refresh(silent);
        },

        id                  : $(el).attr('id'),
        cache               : _cache,
        ignoreCache         : function () {
            return _ignoreCache;
        },
        setIgnoreCache      : function (bool) {
            _ignoreCache = bool;
        },
        initialLimit        : _stateInput.l
    };

    return iw_payload.widgets[$(el).attr('id')];
};

iw_payload.init();
